"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useModifyChildrenProps = void 0;
const sitecore_jss_nextjs_1 = require("@sitecore-jss/sitecore-jss-nextjs");
const react_1 = require("react");
const helpers_1 = require("../helpers");
/**
 * Use this hook to modify the props of the children components (Placeholder).
 * @param rendering The rendering object of the current component.
 * @param newProps  The new props to be added to the children components.
 * @returns The modified props of the children components.
 **/
const useModifyChildrenProps = (rendering, newProps) => {
    const componentPropsCollection = (0, react_1.useContext)(sitecore_jss_nextjs_1.ComponentPropsReactContext);
    const placeholders = (0, helpers_1.filterPlaceholders)(Object.values(rendering.placeholders || {}).flat());
    const modifiedProps = {};
    placeholders.forEach((item) => {
        const key = item.uid;
        const propsContext = componentPropsCollection[key] || {};
        Object.assign(propsContext, newProps);
        componentPropsCollection[key] = propsContext;
        modifiedProps[key] = propsContext;
    });
    return modifiedProps;
};
exports.useModifyChildrenProps = useModifyChildrenProps;
